@@ -235,6 +235,9 @@ function(Symbols,env,return.class='xts',index.class="Date",
      if(!hasArg(verbose)) verbose <- FALSE
      if(!hasArg(auto.assign)) auto.assign <- TRUE
      yahoo.URL <- "http://ichart.finance.yahoo.com/table.csv?"
+
+     tmp <- tempfile()
+     on.exit(unlink(tmp))
      for(i in 1:length(Symbols)) {
        return.class <- getSymbolLookup()[[Symbols[[i]]]]$return.class
        return.class <- ifelse(is.null(return.class),default.return.class,
@@ -254,7 +257,6 @@ function(Symbols,env,return.class='xts',index.class="Date",
        Symbols.name <- getSymbolLookup()[[Symbols[[i]]]]$name
        Symbols.name <- ifelse(is.null(Symbols.name),Symbols[[i]],Symbols.name)
        if(verbose) cat("downloading ",Symbols.name,".....\n\n")
-       tmp <- tempfile()
        download.file(paste(yahoo.URL,
                            "s=",Symbols.name,
                            "&a=",from.m,
@@ -267,7 +269,6 @@ function(Symbols,env,return.class='xts',index.class="Date",
                            "&z=",Symbols.name,"&x=.csv",
                            sep=''),destfile=tmp,quiet=!verbose)
        fr <- read.csv(tmp)
-       unlink(tmp)
        if(verbose) cat("done.\n")
        fr <- xts(as.matrix(fr[,-1]),
                  as.Date(fr[,1]),
@@ -370,8 +371,9 @@ function(Symbols,env,return.class='xts',index.class="Date",
             
             page <- 1
             totalrows <- c()
+            tmp <- tempfile()
+            on.exit(unlink(tmp))
             while (TRUE) {
-                tmp <- tempfile()
                 download.file(paste(yahoo.URL,
                                     "?code=",Symbols.name,
                                     "&sm=",from.m,
@@ -385,8 +387,6 @@ function(Symbols,env,return.class='xts',index.class="Date",
                                     sep=''),destfile=tmp,quiet=!verbose)
                 
                 fdoc <- XML::htmlParse(tmp)
-                unlink(tmp)
-                
                 rows <- XML::xpathApply(fdoc, "//table[@class='boardFin yjSt marB6']//tr")
                 if (length(rows) == 1) break
                 
@@ -397,8 +397,11 @@ function(Symbols,env,return.class='xts',index.class="Date",
             
             # Available columns
             cols <- c('Open','High','Low','Close','Volume','Adjusted')
-            if (grepl(".O$", Symbols.name)) cols <- cols[-(5:6)]
             
+            firstrow <- totalrows[[1]]
+            cells <- XML::getNodeSet(firstrow, "th")
+            if (length(cells) == 5) cols <- cols[-(5:6)]
+
             # Process from the start, for easier stocksplit management
             totalrows <- rev(totalrows)
             mat <- matrix(0, ncol=length(cols) + 1, nrow=0, byrow=TRUE)
@@ -477,11 +480,13 @@ function(Symbols,env,return.class='xts',
      to.y <- as.numeric(strsplit(as.character(to),'-',)[[1]][1])
      to.m <- as.numeric(strsplit(as.character(to),'-',)[[1]][2])
      to.d <- as.numeric(strsplit(as.character(to),'-',)[[1]][3])
+
+     tmp <- tempfile()
+     on.exit(unlink(tmp))
      for(i in 1:length(Symbols)) {
        Symbols.name <- getSymbolLookup()[[Symbols[[i]]]]$name
        Symbols.name <- ifelse(is.null(Symbols.name),Symbols[[i]],Symbols.name)
        if(verbose) cat("downloading ",Symbols.name,".....\n\n")
-       tmp <- tempfile()
        download.file(paste(google.URL,
                            "q=",Symbols.name,
                            "&startdate=",month.abb[from.m],
@@ -493,7 +498,6 @@ function(Symbols,env,return.class='xts',
                            "&output=csv",
                            sep=''),destfile=tmp,quiet=!verbose)
        fr <- read.csv(tmp)
-       unlink(tmp)
        if(verbose) cat("done.\n")
        fr <- fr[nrow(fr):1,] #google data is backwards
        if(fix.google.bug) {
@@ -616,7 +620,7 @@ function(Symbols,env,return.class='xts',
               sQuote('password'),sQuote('dbname'),
               ") is not set"))
         }
-        con <- DBI::dbConnect("MySQL",user=user,password=password,dbname=dbname,host=host,port=port)
+        con <- DBI::dbConnect(RMySQL::MySQL(),user=user,password=password,dbname=dbname,host=host,port=port)
         db.Symbols <- DBI::dbListTables(con)
         if(length(Symbols) != sum(Symbols %in% db.Symbols)) {
           missing.db.symbol <- Symbols[!Symbols %in% db.Symbols]
@@ -661,17 +665,15 @@ function(Symbols,env,return.class='xts',
      }
      if(!hasArg(verbose)) verbose <- FALSE
      if(!hasArg(auto.assign)) auto.assign <- TRUE
-     FRED.URL <- "http://research.stlouisfed.org/fred2/series"
+     FRED.URL <- "https://research.stlouisfed.org/fred2/series"
+
+     tmp <- tempfile()
+     on.exit(unlink(tmp))
      for(i in 1:length(Symbols)) {
        if(verbose) cat("downloading ",Symbols[[i]],".....\n\n")
-       tmp <- tempfile()
-       download.file(paste(FRED.URL,"/",
-                            Symbols[[i]],"/",
-                            "downloaddata/",
-                            Symbols[[i]],".csv",sep=""),
-                            destfile=tmp,quiet=!verbose)
+       URL <- paste(FRED.URL, "/", Symbols[[i]], "/downloaddata/", Symbols[[i]], ".csv", sep="")
+       try.download.file(URL, destfile=tmp, quiet=!verbose, ...)
        fr <- read.csv(tmp,na.string=".")
-       unlink(tmp)
        if(verbose) cat("done.\n")
        fr <- xts(as.matrix(fr[,-1]),
                  as.Date(fr[,1],origin='1970-01-01'),
@@ -755,6 +757,7 @@ function(Symbols,env,
          dir="",
          return.class="xts",
          extension="csv",
+         col.names=c('Open','High','Low','Close','Volume','Adjusted'),
          ...) {
   importDefaults("getSymbols.csv")
   this.env <- environment()
@@ -780,13 +783,6 @@ function(Symbols,env,
     extension <- ifelse(is.null(extension),default.extension,
                            extension)
                    
-    format <- getSymbolLookup()[[Symbols[[i]]]]$format
-    if(is.null(format)) format<-''
-##    if(!is.null(list(...)[['format']])) {
-##        format<-list(...)[['format']] # dots overrides anything we stored in setSymbolLookup
-##        list(...)[['format']]<-NULL # avoid R's "formal argument "format" matched by multiple actual arguments"
-##    }
-
     if(verbose) cat("loading ",Symbols[[i]],".....")
     if(dir=="") {
       sym.file <- paste(Symbols[[i]],extension,sep=".")
@@ -801,10 +797,18 @@ function(Symbols,env,
     fr <- read.csv(sym.file)
     if(verbose)  
       cat("done.\n")
-    fr <- xts(fr[,-1],as.Date(fr[,1],format=format, origin='1970-01-01'),src='csv',updated=Sys.time())
-    colnames(fr) <- paste(toupper(gsub('\\^','',Symbols[[i]])),
-                          c('Open','High','Low','Close','Volume','Adjusted'),
-                             sep='.')
+
+    # ensure date column is character before calling as.Date
+    asDateArgs <- list(x=as.character(fr[,1]))
+    # use format passed via '...', if specified
+    if(hasArg("format"))
+      asDateArgs$format <- format
+    # allow format from setSymbolLookup to override
+    if(!is.null(getSymbolLookup()[[Symbols[[i]]]]$format))
+      asDateArgs$format <- getSymbolLookup()[[Symbols[[i]]]]$format
+
+    fr <- xts(fr[,-1],do.call("as.Date", asDateArgs),src='csv',updated=Sys.time())
+    colnames(fr) <- paste(toupper(gsub('\\^','',Symbols[[i]])),col.names,sep='.')
     fr <- convert.time.series(fr=fr,return.class=return.class)
     Symbols[[i]] <-toupper(gsub('\\^','',Symbols[[i]])) 
     if(auto.assign)
@@ -1038,6 +1042,8 @@ function(Symbols,env,return.class='xts',
      daySpans <- c(7, 30, 60, 90, 180, 364, 728, 1820)
      dateStr <- c("d7", "d30", "d60", "d90", "d180", "y1", "y2", "y5")
 
+     tmp <- tempfile()
+     on.exit(unlink(tmp))
      for(i in 1:length(Symbols)) {
        return.class <- getSymbolLookup()[[Symbols[[i]]]]$return.class
        return.class <- ifelse(is.null(return.class),default.return.class,
@@ -1058,7 +1064,6 @@ function(Symbols,env,return.class='xts',
        }
 
        if(verbose) cat("downloading ",Symbols.name,".....")
-       tmp <- tempfile()
        # Request minimum data from server to fulfill user's request
        dateDiff <- difftime(to, from, units="days")
        dateLoc <- which(daySpans >= dateDiff)
@@ -1080,7 +1085,6 @@ function(Symbols,env,return.class='xts',
          sep="")
        download.file(oanda.URL, destfile=tmp, quiet=!verbose)
        fr <- read.csv(tmp, skip=4, as.is=TRUE, header=TRUE)
-       unlink(tmp)
        fr[,1L] <- as.Date(fr[,1L], origin="1970-01-01")
        fr <- na.omit(fr[,1:2])    # remove period mean/min/max from end of file
        if(is.character(fr[,2L]))  # remove thousands seperator and convert
